# MCP fal.ai Image Server

[![npm version](https://img.shields.io/npm/v/mcp-fal-ai-image.svg)](https://www.npmjs.com/package/mcp-fal-ai-image)
[![Node.js Version](https://img.shields.io/node/v/mcp-fal-ai-image)](https://nodejs.org/)
[![TypeScript](https://img.shields.io/badge/TypeScript-5.8-blue.svg)](https://www.typescriptlang.org/)
[![Open Source](https://badges.frapsoft.com/os/v1/open-source.svg?v=103)](https://github.com/madhusudan-kulkarni/mcp-fal-ai-image)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](LICENSE)

Generate images from text prompts using [fal.ai](https://fal.ai) via the Model Context Protocol (MCP). This project is intended for use as a backend tool in AI IDEs such as Cursor, Windsurf, or any other MCP-compatible editor.

---

## Features
- Text-to-image generation with fal.ai
- Support for multiple models and image sizes
- Simple integration with IDEs via MCP server configuration
- TypeScript source code, open source, MIT-licensed

---

## Setup

**Requirements:**
- Node.js 18 or higher
- fal.ai API key (`FAL_KEY`)

**IDE Integration:**
Add the following to your IDE’s MCP server configuration (for example, in Cursor or Windsurf):

```json
{
  "mcpServers": {
    "fal-ai-image": {
      "command": "npx",
      "args": ["-y", "mcp-fal-ai-image"],
      "env": { "FAL_KEY": "YOUR-FAL-AI-API-KEY" }
    }
  }
}
```

---

## Usage
- Text-to-image generation (tool: `generate-image`)
- Multiple models and image sizes
- CLI and MCP server modes

---

## 📝 Usage

### Tool: `generate-image`

- **prompt** (string, required): Image description
- **model** (string, optional): Model ID (see below)
- **image_size** (string, optional): `square_hd`, `square`, `portrait_4_3`, `portrait_16_9`, `landscape_4_3`, `landscape_16_9`
- **num_images** (int, optional): Default 1

---

<details>
<summary>🧩 Supported Models</summary>

- fal-ai/recraft-v3
- fal-ai/stable-diffusion-v35-large
- fal-ai/flux-lora
- fal-ai/flux-general
- fal-ai/kolors
- fal-ai/stable-cascade
- fal-ai/aura-flow
- fal-ai/flux-pro/v1.1

</details>

---

## 🛠 Troubleshooting

- **`failed to initialize: request failed`**: Ensure your API key is correct and your network allows outbound HTTPS.
- **`npx: command not found`**: Install Node.js 18+ and npm.
- **Still stuck?** [Open an issue](https://github.com/madhusudan-kulkarni/mcp-fal-ai-image/issues).

---

## 🔄 Example MCP Request/Response

**Request:**

```json
{
  "tool": "generate-image",
  "args": {
    "prompt": "A futuristic cityscape at sunset"
  }
}
```

**Response:**

```json
{
  "image_url": "https://fal.ai/generated/abc123.png"
}
```

---

## 🤝 Contributing

Contributions and suggestions are welcome! Please open issues or pull requests on [GitHub](https://github.com/madhusudan-kulkarni/mcp-fal-ai-image).

---

## 🔒 Security

- Your API key is only used locally to authenticate with fal.ai.
- No user data is stored or transmitted except as required by fal.ai API.

---

## 🔗 Links

- [NPM](https://www.npmjs.com/package/mcp-fal-ai-image)
- [GitHub](https://github.com/madhusudan-kulkarni/mcp-fal-ai-image)
- [fal.ai](https://fal.ai)

---

## 🧑‍💻 Advanced Usage (Manual CLI)

If you want to run the MCP server manually (for development, debugging, or advanced use):

```sh
FAL_KEY=your_fal_api_key npx mcp-fal-ai-image
```

---

## 🛡 License

MIT © 2025 ERU, Madhusudan Kulkarni
